@@ -5,4 +5,7 @@ import os
 def add_proxy(config: ProxyModel):
     os.environ['http_proxy'] = config.http_proxy
     os.environ['https_proxy'] = config.https_proxy
-    os.environ['no_proxy'] = os.getenv('no_proxy') + ',' + config.no_proxy   
\ No newline at end of file
+    if os.getenv('no_proxy'):
+        os.environ['no_proxy'] = os.getenv('no_proxy') + ',' + config.no_proxy   
+    else:
+        os.environ['no_proxy'] = config.no_proxy   
\ No newline at end of file
